#
# spec file for package eyedropper
#
# Copyright (c) 2025 mantarimay
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   com.github.finefindus.eyedropper
%bcond_with     warp
%bcond_with     test
%define sname   blueprint-compiler
%define sver    0.8.1
Name:           eyedropper
Version:        2.1.0
Release:        2.1
Summary:        Pick and format colors
License:        GPL-3.0-or-later
URL:            https://github.com/FineFindus/eyedropper
Source0:        %{url}/releases/download/v%{version}/%{name}-%{version}.tar.xz
%if %{with warp}
Source1:        https://gitlab.gnome.org/jwestman/%{sname}/-/archive/v%{sver}/%{sname}-v%{sver}.tar.bz2
BuildRequires:  python3-gobject
Provides:       bundled(blueprint-compiler)
%else
BuildRequires:  blueprint-compiler
%endif
BuildRequires:  appstream-glib
BuildRequires:  cargo-packaging
BuildRequires:  meson
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.7.0
BuildRequires:  desktop-file-utils

%description
An application to pick and format colors.

Features:
- Pick a Color
- Enter a color in Hex-Format
- Parse RGB/RGBA/ARGB Hex-Colors
- View colors in formats
- Customize which formats appear as well as their order
- Generate a palette of different shades

%lang_package

%prep
%autosetup -p1
%if %{with warp}
mkdir subprojects/%{sname}
tar -xf %{SOURCE1} --strip-components 1 -C subprojects/%{sname}
%endif

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%if %{with test}
%check
%meson_test
%endif

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_datadir}/applications/%{lname}.desktop
%{_datadir}/%{name}/
%{_datadir}/glib-2.0/schemas/%{lname}.gschema.xml
%{_datadir}/dbus-1/services/%{lname}.SearchProvider.service
%dir %{_datadir}/gnome-shell/
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/%{lname}.search-provider.ini
%{_datadir}/icons/hicolor/*/apps/%{lname}*.svg
%{_datadir}/metainfo/%{lname}.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Wed May 21 2025 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Disable test: validate-appdata fail on test
* Mon Mar 31 2025 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.1.0
  * RGB decimal notation
  * support for global shortcuts
  * a new way to directly enter colors, without picking them first
* Wed Sep 18 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.1
  * A new color editor allows modifying the picked color
  * The color system has been completely rewritten, now using the
    palette library for more accurate color conversions.
  * If the system does not allow color picking, a warning page is
    now displayed.
- Add meson_test and cleanup spec
* Fri Oct 20 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.0.0
  + Added
  - Show visual feedback when parsing input
  - Apply input with a new button
  - Display colors in overview search
  - Shadow to differentiate colors from background
  - Export palettes to LibreOffice
  - Tooltip on primary menu
  - Czech translation
  - Portuguese translation
  - Parse any format input
  - Allow for different separators in formats
  - Allow for whitespace in formats
  - Allow precision of 0
  - Set a maximum precision of 15
  - Duplicated colors will be removed from the history by
    @gregorni
  - Commanding option for opening the picker
  + Changed
  - Use flat headerbar
  - Show pop-over for export file formats
  - Use GNOME 45 runtime
  - Use CSS lab format
  - Use von Kries Matrix to convert to XYZ
  - Update to libadwaita 1.4
  - Improved settings backend
  - Improved Name sources dialog
  - Removed default precision switch
  - Removed unused debug info
  - Moved to Blueprint
  - Improved Search performance
  + Fixed
  - Hide toast when cancelled
  - Fixed sandbox debug info
  - Use correct screenshot links
  - Fixed clippy lints
  - Fixed typos
  - Remove unused code
- add source blueprint-compiler-v0.8.1: minimal requirement for
  version 1.0.0
- add python3-gobject BuildRequires: fix build blueprint-compiler
- add appstream-glib BuildRequires: for build metadata
* Sun Oct  1 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Rename version from 0.7.0.beta to 0.7.0~beta
* Thu Sep 28 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Revert to version 0.7.0.beta until blueprint-compiler version
  0.10.0 release
* Tue Sep 26 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
